@@ -18,8 +18,7 @@
 
 #include "mauiapp.h"
 #include "fmh.h"
-#include "handy.h"
-#include "utils.h"
+#include "style.h"
 
 #include <QDir>
 #include <QStandardPaths>
@@ -37,9 +36,9 @@
 #include <QIcon>
 #endif
 
-#if defined BUNDLE_MAUI_STYLE
 #include <QQuickStyle>
-#endif
+
+#include <MauiMan/thememanager.h>
 
 #include "../mauikit_version.h"
 
@@ -56,10 +55,12 @@ MauiApp::MauiApp()
         delete m_instance;
         m_instance = nullptr;
     });
-
-    m_darkMode = UTIL::loadSettings("DARK_MODE", "GLOBAL", m_darkMode, true).toBool();
-    m_darkMode = UTIL::loadSettings("DARK_MODE", "UI", m_darkMode, false).toBool();
     
+    connect(m_controls, &CSDControls::enableCSDChanged, [this]()
+    {
+       qDebug() << "CSD ENABLED CHANGED<<<<" << m_controls->enableCSD(); 
+    });
+
     setDefaultMauiStyle();
 }
 
@@ -109,11 +110,8 @@ void MauiApp::setDefaultMauiStyle()
     QIcon::setThemeName("Luv");
 #endif
     
-#if defined BUNDLE_MAUI_STYLE
     Q_INIT_RESOURCE(style);
     QQuickStyle::setStyle("maui-style");
-    qDebug() << QQuickStyle::name();
-#endif
 }
 
 QQuickWindow * MauiApp::window() const
@@ -142,31 +140,6 @@ void MauiApp::setTranslucencyAvailable(const bool &value)
     emit this->translucencyAvailableChanged(m_translucencyAvailable);
 }
 
-bool MauiApp::darkMode() const
-{
-    return m_darkMode;
-}
-
-bool MauiApp::bundledStyle() const
-{
-#if defined BUNDLE_MAUI_STYLE
-    return true;
-#else
-    return false;
-#endif
-}
-
-void MauiApp::setDarkMode(bool darkMode)
-{
-    if (m_darkMode == darkMode)
-        return;
-
-    m_darkMode = darkMode;
-    emit darkModeChanged(m_darkMode);
-
-    UTIL::saveSettings("DARK_MODE", m_darkMode, "UI", false);
-}
-
 MauiApp *MauiApp::qmlAttachedProperties(QObject *object)
 {
     Q_UNUSED(object)
@@ -174,26 +147,38 @@ MauiApp *MauiApp::qmlAttachedProperties(QObject *object)
 }
 
 CSDControls::CSDControls(QObject *parent) : QObject (parent)
-{
-#if !defined Q_OS_ANDROID || defined Q_OS_LINUX || defined Q_OS_FREEBSD // ignore csd for those
-    if (qEnvironmentVariableIsSet("QT_QUICK_CONTROLS_MOBILE"))
-    {
-        if (QByteArrayList {"0", "false"}.contains(qgetenv("QT_QUICK_CONTROLS_MOBILE")))
-        {
-                        this->setEnableCSD(UTIL::loadSettings("CSD", "GLOBAL", m_enableCSD, true).toBool());
-        }
-    }else
-    {
-        this->setEnableCSD(UTIL::loadSettings("CSD", "GLOBAL", m_enableCSD, true).toBool());
-    }
-#endif
+,m_themeSettings( new MauiMan::ThemeManager(this))
+
+{       
+    connect(m_themeSettings, &MauiMan::ThemeManager::enableCSDChanged, [this](bool enabled)
+    {        
+        qDebug() << "CSD ENABLED CHANGED<<<<" << enabled; 
+        
+        if(m_enabledCSD_blocked)
+            return;
+        
+        m_enableCSD = enabled;
+        Q_EMIT enableCSDChanged();
+    });
+    
+    connect(m_themeSettings, &MauiMan::ThemeManager::windowControlsThemeChanged, [this](QString style)
+    {        
+        m_styleName = style;
+        setStyle(); 
+        
+        Q_EMIT styleNameChanged();
+        Q_EMIT sourceChanged();
+    });
+    
+//     connect(this, &CSDControls::styleNameChanged, [this]()
+//     {
+//     });
+    
+    getWindowControlsSettings();     
 }
 
-void CSDControls::getWindowControlsSettings()
-{    
-#if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
-    
-    m_styleName = UTIL::loadSettings("CSDStyle", "GLOBAL", "Nitrux", true).toString();
+void CSDControls::setStyle()
+{
     auto confFile = QStandardPaths::locate (QStandardPaths::GenericDataLocation, QString("org.mauikit.controls/csd/%1/config.conf").arg(m_styleName));
     QFileInfo file(confFile);
     if(file.exists ())
@@ -203,34 +188,42 @@ void CSDControls::getWindowControlsSettings()
         QSettings conf (confFile, QSettings::IniFormat);
         conf.beginGroup ("Decoration");
         m_source = dir.toString()+"/"+ conf.value("Source").toString();
-        m_borderRadius = conf.value ("BorderRadius", 8).toInt();
         conf.endGroup ();
     }
     
     qDebug() << "CSD QML SOURCXE" << m_source;
     m_rightWindowControls =  QStringList {"I", "A", "X"};
-    emit this->rightWindowControlsChanged();
-//     auto kconf = KSharedConfig::openConfig("kwinrc");
-//     const auto group = kconf->group("org.kde.kdecoration2");
-//     
-//     if (group.hasKey("ButtonsOnLeft")) {
-//         m_leftWindowControls = group.readEntry("ButtonsOnLeft", "").split("", Qt::SkipEmptyParts);
-//         emit this->leftWindowControlsChanged();
-//     }
-//     
-//     if (group.hasKey("ButtonsOnRight")) {
-//         m_rightWindowControls = group.readEntry("ButtonsOnRight", "").split("", Qt::SkipEmptyParts);
-//         emit this->rightWindowControlsChanged();
-//     }
+    emit this->rightWindowControlsChanged();    
+}
+
+void CSDControls::getWindowControlsSettings()
+{    
+    #if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
+    if (qEnvironmentVariableIsSet("QT_QUICK_CONTROLS_MOBILE"))
+    {
+        if (QByteArrayList {"0", "false"}.contains(qgetenv("QT_QUICK_CONTROLS_MOBILE")))
+        {
+            m_enableCSD = m_themeSettings->enableCSD();
+        }else
+        {
+            return;    
+        }
+    }else
+    {
+        m_enableCSD = m_themeSettings->enableCSD();
+    }
     
-#elif defined Q_OS_MACOS || defined Q_OS_ANDROID
+    m_styleName = m_themeSettings->windowControlsTheme();
+    setStyle();
+    
+    #elif defined Q_OS_MACOS || defined Q_OS_ANDROID
     m_leftWindowControls = QStringList {"X", "I", "A"};
     emit this->leftWindowControlsChanged();
     
-#elif defined Q_OS_WIN32
+    #elif defined Q_OS_WIN32
     //   m_rightWindowControls = QStringList {"I", "A", "X"};
     emit this->rightWindowControlsChanged();
-#endif
+    #endif
 }
 
 bool CSDControls::enableCSD() const
@@ -240,17 +233,12 @@ bool CSDControls::enableCSD() const
 
 void CSDControls::setEnableCSD(const bool &value)
 {
-        if (m_enableCSD == value)
-            return;
-        
-        m_enableCSD = value;
+    m_enabledCSD_blocked = true;
+    if (m_enableCSD == value)
+        return;
     
-    
-    emit enableCSDChanged();
-    
-    if (m_enableCSD) {
-        getWindowControlsSettings();
-    }
+    m_enableCSD = value;        
+    Q_EMIT enableCSDChanged();
 }
 
 QUrl CSDControls::source() const
@@ -263,18 +251,30 @@ QString CSDControls::styleName() const
     return m_styleName;
 }
 
-int CSDControls::borderRadius() const
-{
-    return m_borderRadius;
-}
-
 CSDButton::CSDButton(QObject *parent): QObject(parent)
 {
     connect(this, &CSDButton::typeChanged, this, &CSDButton::setSources);
+    connect(this, &CSDButton::styleChanged, this, &CSDButton::setSources);
     connect(this, &CSDButton::stateChanged, this, &CSDButton::requestCurrentSource);
     m_style = MauiApp::instance()->controls()->styleName();
 }
 
+void CSDButton::setStyle(const QString& style)
+{
+    if(m_style == style)
+    {
+        return;
+    }
+    
+    m_style = style;
+    Q_EMIT styleChanged();
+}
+
+QString CSDButton::style() const
+{
+    return m_style;
+}
+
 QUrl CSDButton::source() const
 {
     return m_source;
