@@ -26,13 +26,8 @@
 #include "mauikit_export.h"
 
 #include <QSettings>
-#include <QColor>
 
-#if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
-#include <KAboutData>
-#else
 #include <KCoreAddons/KAboutData>
-#endif
 
 /**
  * @brief The MauiApp class
@@ -48,6 +43,12 @@
 
 class QQuickWindow;
 class QQuickItem;
+
+namespace MauiMan
+{
+  class ThemeManager;
+}
+
 class CSDButton : public QObject
 {
   Q_OBJECT
@@ -59,6 +60,7 @@ class CSDButton : public QObject
   Q_PROPERTY(bool isFocused READ isFocused WRITE setIsFocused NOTIFY isFocusedChanged)
   Q_PROPERTY(CSDButtonType type READ type WRITE setType NOTIFY typeChanged)
   Q_PROPERTY(QUrl source READ source NOTIFY sourceChanged FINAL)
+  Q_PROPERTY(QString style READ style WRITE setStyle NOTIFY styleChanged)
   
 public:
   enum CSDButtonState
@@ -103,6 +105,9 @@ public:
   CSDButton::CSDButtonType type() const;
   void setType(CSDButton::CSDButtonType newType);
 
+  QString style() const;
+  void setStyle(const QString &style);
+  
 public slots:
   CSDButton::CSDButtonType mapType(const QString &value);
 
@@ -113,7 +118,8 @@ private:
   CSDButtonState m_state = CSDButtonState::Normal;
 
   CSDButtonSources m_sources; //the state and the source associated
-
+  QString m_style;
+  
   bool m_isHovered;
 
   bool m_isMaximized;
@@ -128,7 +134,6 @@ private:
   void setSources();
   void requestCurrentSource();
 
-  QString m_style;
 
 signals:
   void stateChanged();
@@ -138,6 +143,7 @@ signals:
   void isPressedChanged();
   void isFocusedChanged();
   void typeChanged();
+  void styleChanged();
 };
 
 class CSDControls : public QObject
@@ -146,9 +152,8 @@ class CSDControls : public QObject
   Q_DISABLE_COPY(CSDControls)
   
   Q_PROPERTY(bool enableCSD READ enableCSD WRITE setEnableCSD NOTIFY enableCSDChanged)
-  Q_PROPERTY(QUrl source READ source CONSTANT FINAL)
-  Q_PROPERTY(int borderRadius READ borderRadius CONSTANT FINAL)
-  Q_PROPERTY(QString styleName READ styleName CONSTANT FINAL)
+  Q_PROPERTY(QUrl source READ source NOTIFY sourceChanged FINAL)
+  Q_PROPERTY(QString styleName READ styleName NOTIFY styleNameChanged FINAL)
   Q_PROPERTY(QStringList leftWindowControls MEMBER m_leftWindowControls NOTIFY leftWindowControlsChanged FINAL)
   Q_PROPERTY(QStringList rightWindowControls MEMBER m_rightWindowControls NOTIFY rightWindowControlsChanged FINAL)
 
@@ -171,25 +176,29 @@ public:
      * @param value
      */
   void setEnableCSD(const bool &value);
-  int borderRadius() const;
   QUrl source() const;
   QString styleName() const;
 
 private:
+  MauiMan::ThemeManager *m_themeSettings;
+  
   bool m_enableCSD = false;
+  bool m_enabledCSD_blocked = false;
+  
   QUrl m_source;
-  int m_borderRadius;
   QString m_styleName = "Nitrux";
   QStringList m_leftWindowControls;
   QStringList m_rightWindowControls;
 
   void getWindowControlsSettings();
+  void setStyle();
 
 signals:
   void leftWindowControlsChanged();
   void rightWindowControlsChanged();
   void enableCSDChanged();
-
+  void styleNameChanged();
+  void sourceChanged();
 };
 
 class Notify;
@@ -207,8 +216,6 @@ class MAUIKIT_EXPORT MauiApp : public QObject
     Q_PROPERTY(bool translucencyAvailable READ translucencyAvailable NOTIFY translucencyAvailableChanged)
 //   Q_PROPERTY(QQuickWindow *window READ window WRITE setWindow NOTIFY windowChanged)
 //   Q_PROPERTY(QQuickItem *windowPage READ windowPage WRITE setWindowPage NOTIFY windowPageChanged)
-    Q_PROPERTY(bool darkMode READ darkMode WRITE setDarkMode NOTIFY darkModeChanged)
-    Q_PROPERTY(bool bundledStyle READ bundledStyle CONSTANT FINAL)
   
 public:
   static MauiApp *qmlAttachedProperties(QObject *object);
@@ -277,13 +284,6 @@ public:
   bool translucencyAvailable() const;
   void setTranslucencyAvailable(const bool &value);
 
-  bool darkMode() const;
-
-  bool bundledStyle() const;
-
-public slots:
-  void setDarkMode(bool darkMode);
-
 private:
   static MauiApp *m_instance;
   MauiApp();
@@ -293,13 +293,10 @@ private:
   
   bool m_translucencyAvailable = false;
 
-  bool m_darkMode;  
-
 signals:
   void iconNameChanged();
   void donationPageChanged();
   void translucencyAvailableChanged(bool translucencyAvailable);
-  void darkModeChanged(bool darkMode);
 };
 
 QML_DECLARE_TYPEINFO(MauiApp, QML_HAS_ATTACHED_PROPERTIES)
